## segway 1.2.0.dev-r9225 run ea328b26e5b811e196ff00e0812d10a2 at 2012-08-13 19:36:56.438558

cd "/net/noble/vol4/noble/user/mmh1/src/sci-util/segway/test/simpleseg"
"/net/noble/vol2/home/mmh1/arch/Linux/RHEL6/x86_64/bin/segway" "--cluster-opt=-l rhel=6,testing=TRUE" "--include-coords=../include-coords.bed" "identify" "../simpleseg.genomedata" "traindir" "identifydir"
