## segway 1.2.0.dev-r7941 run 0074b60c84f211e1aa8b000c2997d6ab at 2012-04-12 15:51:12.344128

cd "/net/noble/vol4/noble/user/mmh1/src/sci-util/segway/test/simplereverse"
"/net/noble/vol2/home/mmh1/arch/Linux/RHEL6/x86_64/bin/segway" "--cluster-opt=-l rhel=6,testing=TRUE" "--include-coords=include-coords.bed" "--tracks-from=tracks.txt" "--num-labels=4" "--reverse-world=1" "--dry-run" "train" "simpleconcat.genomedata" "traindir.trackfrom"
