## segway 1.2.0.dev-r7796 run b718c8dc752d11e18930000c2997d6ab at 2012-03-23 14:18:20.468413

cd "/net/noble/vol1/home/epaul9/projects/encode/src/2012/segway/test/simplerecover/test-20120323.WhowhB"
"/net/noble/vol1/home/epaul9/arch/Linux/RHEL6/x86_64/bin/segway" "--cluster-opt=-l rhel=6" "--include-coords=../include-coords.bed" "--tracks-from=../tracks.txt" "--num-labels=4" "train" "../simpleseg.genomedata" "traindir"
